polytopes_db: Databases of 2- and 3-dimensional reflexive polytopes
===================================================================

Description
-----------

This package includes lists of 2- and 3-dimensional reflexive polytopes.

The list of polygons is quite easy to get and it has been known for a
while. The list of 3-polytopes was originally obtained by Maximilian
Kreuzer and Harald Skarke using their software PALP, which is included
into the standard distribution of Sage. To work with lattice and
reflexive polytopes from Sage you can use sage.geometry.lattice_polytope
module, which relies on PALP for some of its functionality. To get
access to the databases of this package, use ReflexivePolytope and
ReflexivePolytopes commands.

License
-------

GPL

Upstream Contact
----------------

http://hep.itp.tuwien.ac.at/~kreuzer/CY/CYpalp.html


